@@ -4,7 +4,8 @@
 #' @export
 #' @return \code{names<-} the updated BibEntry object.
 `names<-.BibEntry` <- function(x, value){
-  x <- mapply(`attr<-`, unclass(x), list('key'), as.list(value), SIMPLIFY = FALSE)
+  x <- mapply(`attr<-`, unclass(x), list('key'), as.list(value),
+              SIMPLIFY = FALSE) 
   class(x) <- c('BibEntry', 'bibentry')
   x <- MakeKeysUnique(x)
   x
