@@ -1,4 +1,5 @@
 #' @keywords internal
+#' @noRd
 AddCite <- function(index, use.hyper = TRUE){
   new.ind <- logical(length(index))
              if (use.hyper)
@@ -18,15 +19,15 @@ AddCite <- function(index, use.hyper = TRUE){
 #' e.g., a RMarkdown or RHTML document.
 #'
 #' @param bib a \code{BibEntry} or \code{bibentry} object
-#' @param ... passed to \code{\link{SearchBib}} for indexing into bib.  A character vector of
-#' keys, for example.
+#' @param ... passed to \code{\link{SearchBib}} for indexing into bib.  A character
+#' vector of keys, for example.
 #' @param textual logical; if TRUE, a \dQuote{textual} citation is produced, i.e.
-#' what is produced by \\citet in \code{natbib} and \\textcite in \code{BibLaTeX}; otherwise,
-#' a parenthetical citation as \\citep and \\autocite.
+#' what is produced by \\citet in \code{natbib} and \\textcite in \code{BibLaTeX};
+#' otherwise, a parenthetical citation as \\citep and \\autocite.
 #' @param before string; optional text to display before the citation.
 #' @param after string; optional text to display after the citation.
-#' @param .opts list; See the relevant section in \code{\link{BibOptions}} for a description
-#' of all valid options for these functions.
+#' @param .opts list; See the relevant section in \code{\link{BibOptions}} for a
+#' description of all valid options for these functions.
 #' @details See the package vignettes and execute the examples below.
 #' @return For the cite functions: a character string containing the citation
 #' @rdname Cite
@@ -37,7 +38,8 @@ AddCite <- function(index, use.hyper = TRUE){
 #' BibOptions(check.entries = FALSE)
 #' bib <- ReadBib(file)
 #' Citet(bib, 12)
-#' Citep(bib, c("loh", "geer"), .opts = list(cite.style = "numeric"), before = "see e.g., ")
+#' Citep(bib, c("loh", "geer"), .opts = list(cite.style = "numeric"),
+#'       before = "see e.g., ")
 #' Citet(bib, "loh", .opts = list(cite.style = "numeric", super = TRUE))
 #' AutoCite(bib, eprinttype = "arxiv", .opts = list(cite.style = "authoryear"))
 #' AutoCite(bib, eprinttype = "arxiv", .opts = list(cite.style = "pandoc"))
@@ -45,7 +47,8 @@ AddCite <- function(index, use.hyper = TRUE){
 #' ## shorthand field in both entries gets used for numeric and alphabetic labels
 #' TextCite(bib, author = "kant", .opts = list(cite.style = "alphabetic"))
 #' TextCite(bib, author = "kant", .opts = list(cite.style = "numeric"))
-#' TextCite(bib, author = "kant", .opts = list(cite.style = "alphabetic", style = "html"))
+#' TextCite(bib, author = "kant", .opts = list(cite.style = "alphabetic",
+#'          style = "html"))
 #' punct <- unlist(BibOptions("bibpunct"))
 #' punct[3:4] <- c("(", ")")
 #' TextCite(bib, 33, .opts = list(bibpunct = punct, cite.style = "alphabetic"))
@@ -86,8 +89,8 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
       if (!length(papers))
         return("")
       if (cite.style == "pandoc"){
-        result <- paste0(paste0("@", names(papers)), collapse = paste0(bibpunct[5L],
-                                                         " "))
+        result <- paste0(paste0("@", names(papers)),
+                         collapse = paste0(bibpunct[5L], " "))
         result <- paste0(before, result, after)
         if (textual)
           result <- paste0(bibpunct[3L], result,
@@ -101,13 +104,13 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
             else paste(cleanupLatex(person$given), collapse = " ")
         }
         authorList <- function(paper){
-          names <- sapply(paper$author, shortName)
+          names <- vapply(paper$author, shortName, "")
           if (!length(names))
-            names <- sapply(paper$editor, shortName)
+            names <- vapply(paper$editor, shortName, "")
           if (!length(names))
             names <- paper$label
           if (!length(names))
-            names <- sapply(paper$translator, shortName)
+            names <- vapply(paper$translator, shortName, "")
           names
         }
 
@@ -121,21 +124,25 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
 
         if (cite.style != "numeric"){
           if (any(!names(bib) %in% names(.cites$labs))){
-            # some entries in bib have note been seen before
-            # note we use bib here instead of papers (the subset) in case
-            # a possible "duplicate" in bib is cited in the future. we want to disambiguate this
-            # By duplicate, I mean we want to distinguish Smith 2008a and Smith 2008b
-            bibstyle <- switch(cite.style, authortitle = "authoryear", cite.style)
-            bib <- sort(bib, sorting = "none", .bibstyle = bibstyle, return.labs = TRUE)
+            ## some entries in bib have note been seen before
+            ## note we use bib here instead of papers (the subset) in case
+            ## a possible "duplicate" in bib is cited in the future. want
+            ## to disambiguate. By duplicate, I mean we want to
+            ## distinguish Smith 2008a and Smith 2008b
+            bibstyle <- switch(cite.style, authortitle = "authoryear",
+                               cite.style)
+            bib <- sort(bib, sorting = "none", .bibstyle = bibstyle,
+                        return.labs = TRUE)
             newinds <- bib$.index
             .labs <- newinds[keys]
             .cites$labs <- c(.cites$labs, newinds)
-          }else{  # all entries in bib have been seen before, get the label from .cites env.
+          }else{
+            ## all entries in bib seen before, get label from .cites env.
             .labs <- .cites$labs[keys]
           }
         }else{
-          first.ind <- if (!length(.cites$labs))  # cite.style has changed, labs have been reset
-                         seq_along(papers)
+          first.ind <- if (!length(.cites$labs))  # cite.style has changed, 
+                         seq_along(papers)        #   labs have been reset 
                        else which(first | !keys %in% names(.cites$labs))
           if (length(first.ind)){
             shorthands <- unlist(papers$shorthand)
@@ -154,8 +161,9 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
         if (alphabetic || numeric){
           year <- structure(.labs, names = NULL)
         }else{
-          year <- structure(unlist(sapply(papers$dateobj,
-                                          MakeAuthorYear()$DateFormatter)), names = NULL)
+          year <- structure(unlist(lapply(papers$dateobj,
+                                          MakeAuthorYear()$DateFormatter)),
+                            names = NULL)
 
           if (any(.labs %in% letters)) # make sure labels are authoryear labels
             year <- paste0(year, .labs)
@@ -166,13 +174,16 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
             authorLists <- lapply(papers, authorList)
             lastAuthors <- NULL
             for (i in seq_len(n)) {
-                authors <- authorLists[[i]]
-              if (length(authors) > max.names && !(first[i]  && longnamesfirst)){
+              authors <- authorLists[[i]]
+              if (length(authors) > max.names && !(first[i]  &&
+                                                   longnamesfirst)){
                 authors <- authors[seq_len(max.names)]
-                authors[length(authors)] <- paste0(authors[length(authors)], ", et al.")
+                authors[length(authors)] <- paste0(authors[length(authors)],
+                                                   ", et al.")
               }else{
                 if (length(authors) > 1L)
-                  authors[length(authors)] <- paste("and", authors[length(authors)])
+                  authors[length(authors)] <- paste("and",
+                                                    authors[length(authors)])
               }
               if (length(authors) > 2L)
                 auth[i] <- paste(authors, collapse = ", ")
@@ -195,7 +206,8 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
           }else{
             result <- paste0(bibpunct[1L], before, year, after, bibpunct[2L])
           }
-          if (super && numeric && (!style %in% c("markdown", "html") || !make.hyper))
+          if (super && numeric && (!style %in% c("markdown", "html") ||
+                                   !make.hyper))
               result <- paste0(auth, "^{", result, "}")
           else if (!super || !numeric) result <- paste0(auth, " ", result)
         }else if (numeric || alphabetic) {
@@ -204,26 +216,31 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
             result <- paste0(auth, bibpunct[6L], " ", year)
         }
         if (make.hyper){
-            url = switch(hyperlink, to.bib = paste0("#bib-", gsub("[^_a-zA-Z0-9-]", "", keys,
-                                        useBytes = TRUE)),
-                       to.doc = sapply(papers, GetURL,
+            url <- switch(hyperlink, to.bib = paste0("#bib-",
+                                                     gsub("[^_a-zA-Z0-9-]", "",
+                                                          keys,
+                                                          useBytes = TRUE)),
+                       to.doc = vapply(papers, GetURL, "", 
                                        flds = c("url", "eprint", "doi"),
                                        to.bib = TRUE),
                        hyperlink)
           if (style == "html"){
             new.links <- if (any(first))
-                             paste(paste("<a id='cite-", gsub("[^_a-zA-Z0-9-]", "", keys[first],
-                                                 useBytes = TRUE), "'></a>", sep = ""),
-                                   collapse = "")
+                             paste(paste("<a id='cite-", gsub("[^_a-zA-Z0-9-]",
+                                                              "", keys[first],
+                                                              useBytes = TRUE),
+                                         "'></a>", sep = ""), collapse = "")
                          else ""
             result <- if (numeric && super && textual)
-                        paste0(auth, "<sup><a href='", url, "'>", result, "</a></sup>")
+                        paste0(auth, "<sup><a href='", url, "'>", result,
+                               "</a></sup>")
                       else paste0("<a href='", url, "'>", result, "</a>")
           }else if(style == "markdown"){
             new.links <- if(any(first))
-                             paste(paste("<a name=cite-", gsub("[^_a-zA-Z0-9-]", "", keys[first],
-                                                 useBytes = TRUE), "></a>", sep = ""),
-                                   collapse = "")
+                             paste(paste("<a name=cite-",
+                                         gsub("[^_a-zA-Z0-9-]", "",
+                                              keys[first], useBytes = TRUE),
+                                         "></a>", sep = ""), collapse = "")
             else ""
             result <- if (numeric && super && textual)
                         paste0(auth, "^[", result, "](", url, ")")
@@ -252,14 +269,16 @@ Cite <- function(bib, ..., textual = FALSE, before = NULL, after = NULL,
 #' @export
 #' @aliases TextCite AutoCite Citep Citet
 #' @details If \code{bib.style = "alphabetic"} or \code{bib.style = "numeric"},
-#' then sorting needs to be done at the start of the document prior to using a cite function as
-#' sorting is not done by the Printbibliography function for those styles (specifying
-#' \code{sorting} in \code{.opts} is ignored in this case).  If no sorting is none,
-#' the references are listed in the order they were cited in for those two styles.
+#' then sorting needs to be done at the start of the document prior to using a cite
+#' function as sorting is not done by the Printbibliography function for those styles
+#' (specifying \code{sorting} in \code{.opts} is ignored in this case).  If no sorting
+#' is none, the references are listed in the order they were cited in for those
+#' two styles.
 #'
-#' If the \code{...} argument to NoCite is identical to \dQuote{*}, then all references
-#' in \code{bib} are added to the bibliography without citations.
-#' @seealso \code{\link{print.BibEntry}}, \code{\link{BibOptions}}, \code{\link[utils]{citeNatbib}}
+#' If the \code{...} argument to NoCite is identical to \dQuote{*}, then all
+#' references in \code{bib} are added to the bibliography without citations.
+#' @seealso \code{\link{print.BibEntry}}, \code{\link{BibOptions}},
+#' \code{\link[utils]{citeNatbib}}
 #' @rdname Cite
 PrintBibliography <- function(bib, .opts = list()){
   if (!length(bib))
@@ -284,7 +303,8 @@ PrintBibliography <- function(bib, .opts = list()){
               else .BibOptions$style
 
   bib <- bib[[ind]]
-  # if bibstyle and citation style match, use citation labels, otherwise recompute them
+  ## if bibstyle and citation style match, use citation labels, otherwise
+  ##   recompute them
   if (bibstyle == citestyle){
     if (bibstyle == "numeric"){
       if (length(bib) == length(.cites$labs)){
@@ -319,7 +339,7 @@ Citep <- function(bib, ..., before = NULL, after = NULL,
   ## kall[[1L]] <- as.name("Cite")
   ## kall$textual <- FALSE
   ## eval(kall)
-  Cite(bib, ..., textual = FALSE, before = before, after = after, .opts = .opts)
+  Cite(bib, ..., textual = FALSE, before = before, after = after, .opts=.opts)
 }
 
 #' @export
@@ -356,6 +376,7 @@ TextCite <- function(bib, ..., before = NULL, after = NULL,
 }
 
 #' @keywords internal
+#' @noRd
 ClearLabs <- function(sty){
   .cites$labs <- character(0)
   .cites$sty <- sty
@@ -382,12 +403,15 @@ NoCite <- function(bib, ..., .opts = list()){
   keys <- unlist(papers$key)
   if (.BibOptions$cite.style != "numeric"){
     if (!all(names(bib) %in% names(.cites$labs))){
-      # some entries in bib have note been seen before
-      # note we use bib here instead of papers (the subset) in case
-      # a possible "duplicate" in bib is cited in the future. we want to disambiguate this
-      # By duplicate, I mean we want to distinguish Smith 2008a and Smith 2008b
-      bibstyle <- switch(.BibOptions$cite.style, authortitle = "authoryear", .BibOptions$cite.style)
-      bib <- sort(bib, sorting = "none", .bibstyle = bibstyle, return.labs = TRUE)
+      ## some entries in bib have note been seen before
+      ## note we use bib here instead of papers (the subset) in case
+      ## a possible "duplicate" in bib is cited in the future. we want
+      ## to disambiguate; by duplicate, I mean we want to distinguish
+      ## Smith 2008a and Smith 2008b
+      bibstyle <- switch(.BibOptions$cite.style, authortitle = "authoryear",
+                           .BibOptions$cite.style)
+      bib <- sort(bib, sorting = "none", .bibstyle = bibstyle,
+                  return.labs = TRUE)
       .cites$labs <- c(.cites$labs, bib$.index)
     }
   }else{
